@@ -1,6 +1,7 @@
-import json
+import jsonpickle
 import time
 
+
 class HivePubSub:
     def subscribe_raw(self, topic, callback):
         """
@@ -60,56 +61,39 @@ class Subscriber:
     ):
         pubsub.subscribe_raw(
             topic,
-            Subscriber.raw_handler(cls, decoder, callback)
+            lambda obj: callback(decoder(cls, obj))
         )
 
-    @staticmethod
-    def raw_handler(cls, decoder, callback):
-        def handler(b):
-            callback(decoder(cls, b))
-        return handler
+
+def json_encoder(cls, obj):
+    return jsonpickle.encode(obj, unpicklable=False).encode("utf-8")
 
 
-class JsonEncoder:
-    def __call__(self, cls, obj):
-        if cls == dict:
-            d = obj
-        else:
-            d = obj.__dict__
-        return json.dumps(d).encode("utf-8")
+def json_decoder(cls, msg_bytes):
+    d = jsonpickle.decode(msg_bytes.decode("utf-8"))
+    if type(d) == cls:
+        return d
+
+    msg_bytes = cls()
+    for k, v in d.items():
+        setattr(msg_bytes, k, v)
+    return msg_bytes
 
 
-class JsonDecoder:
+class HiveWorker:
 
-    @staticmethod
-    def dict_to_obj(cls):
-        def builder(d):
-            obj = cls()
-            for key, value in d.items():
-                setattr(obj, key, value)
-            return obj
+    pubsub_cls = HivePubSub
+    encoder = json_encoder
+    decoder = json_decoder
 
-        return builder
-
-    def __call__(self, cls, bytes):
-        return json.loads(bytes.decode("utf-8"), object_hook=JsonDecoder.dict_to_obj(cls))
-
-
-class Hive:
-    DEFAULT_PUBSUB = HivePubSub
-    DEFAULT_ENCODER = JsonEncoder
-    DEFAULT_DECODER = JsonDecoder
-
-    def __init__(self, pubsub=None, encoder=None, decoder=None,):
-        self.pubsub = (pubsub or Hive.DEFAULT_PUBSUB())
-        self.encoder = (encoder or Hive.DEFAULT_ENCODER())
-        self.decoder = (decoder or Hive.DEFAULT_DECODER())
+    def __init__(self, *args, **kwargs):
+        self.pubsub = HiveWorker.pubsub_cls(*args, **kwargs)
 
     def spin(self):
         self.pubsub.spin()
 
     def publisher(self, topic, cls):
-        return Publisher(self.pubsub, topic, cls, self.encoder)
+        return Publisher(self.pubsub, topic, cls, HiveWorker.encoder)
 
     def subscribe(self, topic, cls, callback):
-        return Subscriber(self.pubsub, topic, cls, self.decoder, callback)
+        return Subscriber(self.pubsub, topic, cls, HiveWorker.decoder, callback)
