@@ -1,4 +1,4 @@
-from hive.core import HivePubSub, Hive
+from hive.core import HivePubSub
 import redis
 
 
@@ -25,6 +25,3 @@ class HiveRedis(HivePubSub):
                 for cb in self.subscriptions[msg["channel"].decode("utf-8")]:
                     cb(msg["data"])  # adjusting for hive working in bytes
 
-
-if Hive.DEFAULT_PUBSUB == HivePubSub:
-    Hive.DEFAULT_PUBSUB = HiveRedis
