@@ -3,7 +3,7 @@ import uuid
 
 import stomp
 
-from hive.core import HivePubSub, Hive
+from hive.core import HivePubSub
 
 class Listener(stomp.ConnectionListener):
 
@@ -43,6 +43,3 @@ class HiveStomp(HivePubSub):
     def __del__(self):
         self.client.disconnect()
 
-
-if Hive.DEFAULT_PUBSUB == HivePubSub:
-    Hive.DEFAULT_PUBSUB = HiveStomp
